@@ -11,25 +11,10 @@ use lemmy_api_common::{
   password_length_check,
   person::*,
 };
-use lemmy_db_queries::{
+use lemmy_db_schema::{
   diesel_option_overwrite,
   diesel_option_overwrite_to_url,
   from_opt_str_to_opt_enum,
-  source::{
-    comment::Comment_,
-    community::Community_,
-    local_user::LocalUser_,
-    password_reset_request::PasswordResetRequest_,
-    person::Person_,
-    person_mention::PersonMention_,
-    post::Post_,
-    private_message::PrivateMessage_,
-  },
-  Blockable,
-  Crud,
-  SortType,
-};
-use lemmy_db_schema::{
   naive_now,
   source::{
     comment::Comment,
@@ -44,12 +29,15 @@ use lemmy_db_schema::{
     private_message::PrivateMessage,
     site::*,
   },
+  traits::{Blockable, Crud},
+  SortType,
 };
 use lemmy_db_views::{
   comment_report_view::CommentReportView,
-  comment_view::CommentQueryBuilder,
+  comment_view::{CommentQueryBuilder, CommentView},
   local_user_view::LocalUserView,
   post_report_view::PostReportView,
+  private_message_view::PrivateMessageView,
 };
 use lemmy_db_views_actor::{
   community_moderator_view::CommunityModeratorView,
@@ -203,6 +191,7 @@ impl Perform for SaveUserSettings {
     let default_listing_type = data.default_listing_type;
     let default_sort_type = data.default_sort_type;
     let password_encrypted = local_user_view.local_user.password_encrypted;
+    let public_key = local_user_view.person.public_key;
 
     let person_form = PersonForm {
       name: local_user_view.person.name,
@@ -219,7 +208,7 @@ impl Perform for SaveUserSettings {
       local: None,
       admin: None,
       private_key: None,
-      public_key: None,
+      public_key,
       last_refreshed_at: None,
       shared_inbox_url: None,
       matrix_user_id,
@@ -809,15 +798,16 @@ impl Perform for GetReportCount {
       get_local_user_view_from_jwt(&data.auth, context.pool(), context.secret()).await?;
 
     let person_id = local_user_view.person.id;
+    let admin = local_user_view.person.admin;
     let community_id = data.community_id;
 
     let comment_reports = blocking(context.pool(), move |conn| {
-      CommentReportView::get_report_count(conn, person_id, community_id)
+      CommentReportView::get_report_count(conn, person_id, admin, community_id)
     })
     .await??;
 
     let post_reports = blocking(context.pool(), move |conn| {
-      PostReportView::get_report_count(conn, person_id, community_id)
+      PostReportView::get_report_count(conn, person_id, admin, community_id)
     })
     .await??;
 
@@ -830,3 +820,43 @@ impl Perform for GetReportCount {
     Ok(res)
   }
 }
+
+#[async_trait::async_trait(?Send)]
+impl Perform for GetUnreadCount {
+  type Response = GetUnreadCountResponse;
+
+  async fn perform(
+    &self,
+    context: &Data<LemmyContext>,
+    _websocket_id: Option<ConnectionId>,
+  ) -> Result<Self::Response, LemmyError> {
+    let data = self;
+    let local_user_view =
+      get_local_user_view_from_jwt(&data.auth, context.pool(), context.secret()).await?;
+
+    let person_id = local_user_view.person.id;
+
+    let replies = blocking(context.pool(), move |conn| {
+      CommentView::get_unread_replies(conn, person_id)
+    })
+    .await??;
+
+    let mentions = blocking(context.pool(), move |conn| {
+      PersonMentionView::get_unread_mentions(conn, person_id)
+    })
+    .await??;
+
+    let private_messages = blocking(context.pool(), move |conn| {
+      PrivateMessageView::get_unread_messages(conn, person_id)
+    })
+    .await??;
+
+    let res = Self::Response {
+      replies,
+      mentions,
+      private_messages,
+    };
+
+    Ok(res)
+  }
+}
